@@ -174,6 +174,16 @@ class Py42LegalHoldNotFoundOrPermissionDeniedError(Py42ForbiddenError):
         )
 
 
+class Py42LegalHoldCriteriaMissingError(Py42BadRequestError):
+    """An exception raised when a bad request was made to a Legal Hold endpoint."""
+
+    def __init__(self, exception):
+        super(Py42LegalHoldCriteriaMissingError, self).__init__(
+            exception,
+            u"At least one criteria must be specified; hold_membership_uid, hold_uid, user_uid, or user.",
+        )
+
+
 class Py42InvalidRuleOperationError(Py42HTTPError):
     """An exception raised when trying to add or remove users to a system rule."""
 
@@ -237,6 +247,46 @@ class Py42UserNotOnListError(Py42NotFoundError):
         super(Py42NotFoundError, self).__init__(exception, message)
 
 
+class Py42InvalidRuleError(Py42NotFoundError):
+    """An exception raised when the observer rule ID does not exist."""
+
+    def __init__(self, exception, rule_id):
+        message = u"Invalid Observer Rule ID '{}'.".format(rule_id)
+        super(Py42NotFoundError, self).__init__(exception, message)
+
+
+class Py42UpdateClosedCaseError(Py42BadRequestError):
+    """An error raised when trying to update a closed case."""
+
+    def __init__(self, exception):
+        msg = "Cannot update a closed case."
+        super(Py42UpdateClosedCaseError, self).__init__(exception, msg)
+
+
+class Py42CaseNameExistsError(Py42BadRequestError):
+    """An error raised when trying to create a case with a name that already exists."""
+
+    def __init__(self, exception, case_name):
+        msg = "Case name '{}' already exists, please set another name".format(case_name)
+        super(Py42CaseNameExistsError, self).__init__(exception, msg)
+
+
+class Py42DescriptionLimitExceededError(Py42BadRequestError):
+    """An error raised when description of a case exceeds the allowed char length limit."""
+
+    def __init__(self, exception):
+        msg = "Description limit exceeded, max 250 characters allowed."
+        super(Py42DescriptionLimitExceededError, self).__init__(exception, msg)
+
+
+class Py42CaseAlreadyHasEventError(Py42BadRequestError):
+    """An error raised when event is already associated to the case."""
+
+    def __init__(self, exception):
+        msg = "Event is already associated to the case."
+        super(Py42CaseAlreadyHasEventError, self).__init__(exception, msg)
+
+
 def raise_py42_error(raised_error):
     """Raises the appropriate :class:`py42.exceptions.Py42HttpError` based on the given
     HTTPError's response status code.
