@@ -23,3 +23,9 @@ class PublicIPAddress(FileEventFilterStringField):
     """Class that filters events by public (WAN) IP address of the device that observed the event."""
 
     _term = u"publicIpAddress"
+
+
+class DeviceSignedInUserName(FileEventFilterStringField):
+    """Class that filters events by signed in user of the device that observed the event."""
+
+    _term = u"operatingSystemUser"
