@@ -37,7 +37,7 @@ class V3Auth(C42RenewableAuth):
     def _get_credentials(self):
         uri = u"/c42api/v3/auth/jwt"
         params = {u"useBody": True}
-        currentToken = self._totp()
-        headers = {"totp-auth": str(currentToken)} if currentToken else None
+        current_token = self._totp()
+        headers = {"totp-auth": str(current_token)} if current_token else None
         response = self._auth_connection.get(uri, params=params, headers=headers)
         return u"v3_user_token {}".format(response["v3_user_token"])
