@@ -26,8 +26,6 @@ ROOT_SESSION = Session()
 ROOT_SESSION.mount(u"https://", SESSION_ADAPTER)
 ROOT_SESSION.mount(u"http://", SESSION_ADAPTER)
 ROOT_SESSION.headers = {
-    u"Accept": u"application/json",
-    u"Content-Type": u"application/json",
     u"Accept-Encoding": u"gzip, deflate",
     u"Connection": u"keep-alive",
 }
@@ -184,7 +182,6 @@ class Connection(object):
                 auth=auth,
                 hooks=hooks,
             )
-
             response = self._session.send(
                 request,
                 stream=stream,
@@ -228,14 +225,17 @@ class Connection(object):
         if json is not None:
             data = json_lib.dumps(json)
 
-        user_headers = {u"User-Agent": settings.get_user_agent_string()}
-        if headers:
-            user_headers.update(headers)
-        self._headers.update(user_headers)
+        headers = headers or {}
+        headers.update(self._headers)
+        if data and u"Content-Type" not in headers:
+            headers.update({u"Content-Type": u"application/json"})
+        if u"Accept" not in headers:
+            headers.update({u"Accept": u"application/json"})
+        headers = _create_user_headers(headers)
         request = Request(
             method=method,
             url=url,
-            headers=self._headers,
+            headers=headers,
             files=files,
             data=data,
             params=params,
@@ -263,6 +263,13 @@ class Connection(object):
         self._host_address = host
 
 
+def _create_user_headers(headers):
+    user_headers = {u"User-Agent": settings.get_user_agent_string()}
+    if headers:
+        user_headers.update(headers)
+    return user_headers
+
+
 def _handle_error(method, url, response):
     if response is None:
         msg = u"No response was returned for {} request to {}.".format(method, url)
